@@ -10,17 +10,17 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.03';
-$DATE = '2003/06/15';
+$VERSION = '0.04';
+$DATE = '2003/07/05';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Docs_US_DOD_STD2167A.pm' => [qw(0.03 2003/06/15), 'revised 0.02'],
-    'MANIFEST' => [qw(0.03 2003/06/15), 'generated, replaces 0.02'],
-    'Makefile.PL' => [qw(0.03 2003/06/15), 'generated, replaces 0.02'],
-    'README' => [qw(0.03 2003/06/15), 'generated, replaces 0.02'],
-    'lib/Docs/US_DOD/CDRL.pm' => [qw(1.06 2003/06/10), 'unchanged'],
+    'lib/Docs/Site_SVD/Docs_US_DOD_STD2167A.pm' => [qw(0.04 2003/07/05), 'revised 0.03'],
+    'MANIFEST' => [qw(0.04 2003/07/05), 'generated, replaces 0.03'],
+    'Makefile.PL' => [qw(0.04 2003/07/05), 'generated, replaces 0.03'],
+    'README' => [qw(0.04 2003/07/05), 'generated, replaces 0.03'],
+    'lib/Docs/US_DOD/CDRL.pm' => [qw(1.07 2003/07/05), 'revised 1.06'],
     'lib/Docs/US_DOD/COM.pm' => [qw(1.07 2003/06/10), 'unchanged'],
     'lib/Docs/US_DOD/CPM.pm' => [qw(1.07 2003/06/10), 'unchanged'],
     'lib/Docs/US_DOD/CRISD.pm' => [qw(1.06 2003/06/10), 'unchanged'],
@@ -54,20 +54,20 @@ use vars qw(%INVENTORY);
     'lib/Docs/US_DOD/SUM.pm' => [qw(1.08 2003/06/14), 'unchanged'],
     'lib/Docs/US_DOD/SVD.pm' => [qw(1.08 2003/06/10), 'unchanged'],
     'lib/Docs/US_DOD/VDD.pm' => [qw(1.06 2003/06/10), 'unchanged'],
-    't/Docs/US_DOD/STD2167A.t' => [qw(0.06 2003/06/14), 'unchanged'],
+    't/Docs/US_DOD/STD2167A.t' => [qw(0.07 2003/07/05), 'revised 0.06'],
 
 );
 
 ########
-# The SVD::SVDmaker module uses the data after the __DATA__ 
-# token to automatically generate the this file.
+# The ExtUtils::SVDmaker module uses the data after the __DATA__ 
+# token to automatically generate this file.
 #
 # Don't edit anything before __DATA_. Edit instead
 # the data after the __DATA__ token.
 #
 # ANY CHANGES MADE BEFORE the  __DATA__ token WILL BE LOST
 #
-# the next time SVD::SVDmaker generates this file.
+# the next time ExtUtils::SVDmaker generates this file.
 #
 #
 
@@ -81,11 +81,11 @@ use vars qw(%INVENTORY);
 
  Software Development Standards, Specifications and Data Item Description PODs
 
- Revision: A
+ Revision: C
 
- Version: 0.03
+ Version: 0.04
 
- Date: 2003/06/15
+ Date: 2003/07/05
 
  Prepared for: General Public 
 
@@ -100,32 +100,15 @@ use vars qw(%INVENTORY);
 This paragraph identifies and provides an overview
 of the released files.
 
-=head2 1.1 Indentification
+=head2 1.1 Identification
 
-This release is a collection of Perl modules that
+This release,
+identified in L<3.2|/3.2 Inventory of software contents>,
+is a collection of Perl modules that
 extend the capabilities of the Perl language.
 
 =head2 1.2 System overview
 
-The system is the Perl programming language software.
-The system does not have any hardware.
-The Perl programming language contains two features that
-are utilized by this release:
-
-=over 4
-
-=item 1
-
-Program Modules to extend the languages
-
-=item 2
-
-Plain Old Documentation (POD) that may be embedded in the language
-
-=back
-
-These features are established by the referenced documents.
-
 This release adds United States Department of Defense (US DOD) 
 Perl Plain Old Documentation (POD)
 derived from software related documents release by the
@@ -158,11 +141,24 @@ MANIFEST, updates file versions and creates .tar.gz distribution
 file from a SVD text database in a format consistent with
 L<DataPort::FileType::FormDB>.
 
+The dependency of the program modules in the US DOD STD2167A bundle is as follows:
+ 
+ File::Package File::SmartNL File::TestPath Text::Scrub
+
+     Test::Tech
+
+        DataPort::FileType::FormDB DataPort::DataFile DataPort::Maker 
+        File::AnySpec File::Data File::PM2File File::SubPM Text::Replace 
+        Text::Table
+
+            Test::STDmaker ExtUtils::SVDmaker
+
+
 =back
 
 =head2 1.3 Document overview.
 
-This document releases Docs-US_DOD-STD2167A version 0.03 and
+This document releases Docs-US_DOD-STD2167A version 0.04 and
 provides a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -175,24 +171,27 @@ system file specification.
 
 =head2 3.1 Inventory of materials released.
 
-=head2 3.1.1 Files.
-
 This document releases the file found
-at the following repository:
+at the following repository(s):
 
-   http://www.softwarediamonds/packages/Docs-US_DOD-STD2167A-0.03
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Docs-US_DOD-STD2167A-0.03
+   http://www.softwarediamonds/packages/Docs-US_DOD-STD2167A-0.04
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Docs-US_DOD-STD2167A-0.04
 
 
-=head2 3.1.2 Copyright.
+Restrictions regarding duplication and license provisions
+are as follows:
+
+=over 4
+
+=item Copyright.
 
 copyright  2003 Software Diamonds
 
-=head2 3.1.3 Copyright holder contact.
+=item Copyright holder contact.
 
  603 882-0846 E<lt>support@SoftwareDiamonds.comE<gt>
 
-=head2 3.1.4 License.
+=item License.
 
 These files are a POD derived works from the hard copy public domain version
 freely distributed by the United States Federal Government.
@@ -244,6 +243,8 @@ OR TORT (INCLUDING USE OF THIS SOFTWARE, EVEN IF
 ADVISED OF NEGLIGENCE OR OTHERWISE) ARISING IN
 ANY WAY OUT OF THE POSSIBILITY OF SUCH DAMAGE.
 
+=back
+
 =head2 3.2 Inventory of software contents
 
 The content of the released, compressed, archieve file,
@@ -251,11 +252,11 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Docs_US_DOD_STD2167A.pm                    0.03    2003/06/15 revised 0.02
- MANIFEST                                                     0.03    2003/06/15 generated, replaces 0.02
- Makefile.PL                                                  0.03    2003/06/15 generated, replaces 0.02
- README                                                       0.03    2003/06/15 generated, replaces 0.02
- lib/Docs/US_DOD/CDRL.pm                                      1.06    2003/06/10 unchanged
+ lib/Docs/Site_SVD/Docs_US_DOD_STD2167A.pm                    0.04    2003/07/05 revised 0.03
+ MANIFEST                                                     0.04    2003/07/05 generated, replaces 0.03
+ Makefile.PL                                                  0.04    2003/07/05 generated, replaces 0.03
+ README                                                       0.04    2003/07/05 generated, replaces 0.03
+ lib/Docs/US_DOD/CDRL.pm                                      1.07    2003/07/05 revised 1.06
  lib/Docs/US_DOD/COM.pm                                       1.07    2003/06/10 unchanged
  lib/Docs/US_DOD/CPM.pm                                       1.07    2003/06/10 unchanged
  lib/Docs/US_DOD/CRISD.pm                                     1.06    2003/06/10 unchanged
@@ -289,11 +290,17 @@ consists of the following files:
  lib/Docs/US_DOD/SUM.pm                                       1.08    2003/06/14 unchanged
  lib/Docs/US_DOD/SVD.pm                                       1.08    2003/06/10 unchanged
  lib/Docs/US_DOD/VDD.pm                                       1.06    2003/06/10 unchanged
- t/Docs/US_DOD/STD2167A.t                                     0.06    2003/06/14 unchanged
+ t/Docs/US_DOD/STD2167A.t                                     0.07    2003/07/05 revised 0.06
 
 
 =head2 3.3 Changes
 
+Changes are as follows:
+
+=over 4
+
+=item Docs::US_DOD::STD2167A 0.03
+
 Retarded. Sorry testers. 
 
 Version 0.02 loaded test file t/Docs/US_DOD/STD2167A.t but
@@ -311,6 +318,16 @@ To:
 
  t/Docs/US_DOD/STD2167A.t
 
+
+=item Docs::US_DOD::STD2167A 0.04
+
+Another case insensitive issue. The STrP has one lower case
+letter. Make changes so everything should match the case.
+Unix file specifications are case sensitive while
+Microsoft's are not.
+
+=back
+
 =head2 3.4 Adaptation data.
 
 This installation requires that the installation site
@@ -335,6 +352,13 @@ test of this release.
 
 =head2 3.6 Installation instructions.
 
+Instructions for installation, installation tests
+and installation support are as follows:
+
+=over 4
+
+=item Installation Instructions.
+
 To installed the release file, use the CPAN module in the Perl release
 or the INSTALL.PL script at the following web site:
 
@@ -344,23 +368,34 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/Docs-US_DOD-STD2167A-0.03
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Docs-US_DOD-STD2167A-0.03
+   http://www.softwarediamonds/packages/Docs-US_DOD-STD2167A-0.04
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Docs-US_DOD-STD2167A-0.04
 
 
-=head2 3.6.1 Installation support.
+=item Prerequistes.
+
+ None.
+
+
+=item Security, privacy, or safety precautions.
+
+None.
+
+=item Installation Tests.
+
+Most Perl installation software will run the following test script(s)
+as part of the installation:
+
+ t/Docs/US_DOD/STD2167A.t
+
+=item Installation support.
 
 If there are installation problems or questions with the installation
 contact
 
  603 882-0846 E<lt>support@SoftwareDiamonds.comE<gt>
 
-=head2 3.6.2 Installation Tests.
-
-Most Perl installation software will run the following test script(s)
-as part of the installation:
-
- t/Docs/US_DOD/STD2167A.t
+=back
 
 =head2 3.7 Possible problems and known errors
 
@@ -419,78 +454,122 @@ extension for a Software Vesion Description database file
 
 =head1 2.0 SEE ALSO
 
-The following documents establish the requirements for Perl Modules and
-PODs:
+Modules with end-user functional interfaces 
+relating to US DOD 2167A automation are
+as follows:
 
 =over 4
 
-=item Programing Perl
+=item L<Test::STDmaker|Test::STDmaker>
 
-Programming Perl, Third Edition, by Larry Wall, Tom Christiansen and Jon Orwant
+=item L<ExtUtils::SVDmaker|ExtUtils::SVDmaker>
 
-=item US DOD 2167A Standards, DIDs and related Documents
+=item L<DataPort::FileType::FormDB|DataPort::FileType::FormDB>
 
-=over 4
+=item L<DataPort::DataFile|DataPort::DataFile>
 
-=item  L<[Computer Operation Manual (COM) DID]|Docs::US_DOD::COM>
+=item L<Test::Tech|Test::Tech>
 
-=item L<[Computer Programming Manual (CPM) DID)]|Docs::US_DOD::CPM>
+=item L<Test|Test>
 
-=item L<[Computer Resources Integrated Support Document (CRISD) DID]|Docs::US_DOD::CRISD>
+=item L<Data::Dumper|Data::Dumper>
 
-=item L<[Computer System Operator's Manual (CSOM) DID]|Docs::US_DOD::CSOM>
+=item L<Test::STD::Scrub|Test::STD::Scrub>
 
-=item L<[Database Design Description (DBDD) DID]|Docs::US_DOD::DBDD>
+=item L<Test::STD::STDutil|Test::STD::STDutil>
 
-=item L<[Engineering Change Proposal (ECP) DID]|Docs::US_DOD::ECP>
-
-=item L<[Firmware support Manual (FSM) DID]|Docs::US_DOD::FSM>
-
-=item L<Interface Design Document (IDD) DID]|Docs::US_DOD::IDD>
-
-=item L<[Interface Requirements Specification (IRS) DID]|Docs::US_DOD::IRS>
-
-=item L<[Operation Concept Description (OCD) DID]|Docs::US_DOD::OCD>
-
-=item L<[Specification Change Notice (SCN) DID]|Docs::US_DOD::SCN>
-
-=item L<[Software Design Specification (SDD) DID]|Docs::US_DOD::SDD>
-
-=item L<[Software Development Plan (SDP) DID]|Docs::US_DOD::SDP> 
-
-=item L<[Software Input and Output Manual (SIOM) DID]|Docs::US_DOD::SIOM>
-
-=item L<[Software Installation Plan (SIP) DID]|Docs::US_DOD::SIP>
-
-=item L<[Software Programmer's Manual (SPM) DID]|Docs::US_DOD::SPM>
-
-=item L<[Software Product Specification (SPS) DID]|Docs::US_DOD::SPS>
-
-=item L<[Software Requirements Specification (SRS) DID]|Docs::US_DOD::SRS>
-
-=item L<[System or Segment Design Document (SSDD) DID]|Docs::US_DOD::SSDD>
-
-=item L<[System or Subsystem Specification (SSS) DID]|Docs::US_DOD::SSS>
-
-=item L<[Software Test Description (STD) DID]|Docs::US_DOD::STD>
-
-=item L<[Software Test Plan (STP) DID]|Docs::US_DOD::STP>
-
-=item L<[Software Test Report (STR) DID]|Docs::US_DOD::STR>
-
-=item L<[Software Transition Plan (STrP) DID]|Docs::US_DOD::STrP>
-
-=item L<[Software User Manual (SUM) DID]|Docs::US_DOD::SUM>
-
-=item L<[Software Version Description (SVD) DID]|Docs::US_DOD::SVD>
-
-=item L<[Version Description Document (VDD) DID]|Docs::US_DOD::VDD>
+=item L<File::FileUtil|File::FileUtil>
 
 =back
 
-=item US DOD STD2167A Automation
+The design modules for L<Test::STDmaker|Test::STDmaker>
+have no other conceivable use then to support the
+L<Test::STDmaker|Test::STDmaker> functional interface. 
+The  L<Test::STDmaker|Test::STDmaker>
+design module are as follows:
 
-L<[Test::STDmaker]|Test::STDmaker> L<[ExtUtils::SVDmaker]|ExtUtils::SVDmaker>
+=over 4
+
+=item L<Test::STD::Check|Test::STD::Check>
+
+=item L<Test::STD::FileGen|Test::STD::FileGen>
+
+=item L<Test::STD::STD2167|Test::STD::STD2167>
+
+=item L<Test::STD::STDgen|Test::STD::STDgen>
+
+=item L<Test::STDtype::Demo|Test::STDtype::Demo>
+
+=item L<Test::STDtype::STD|Test::STDtype::STD>
+
+=item L<Test::STDtype::Verify|Test::STDtype::Verify>
+
+=back
+
+
+Some US DOD 2167A Software Development Standard, DIDs and
+other related documents that complement the 
+US DOD 2167A automation are as follows:
+
+=over 4
+
+=item L<US DOD Software Development Standard|Docs::US_DOD::STD2167A>
+
+=item L<US DOD Specification Practices|Docs::US_DOD::STD490A>
+
+=item L<Computer Operation Manual (COM) DID|Docs::US_DOD::COM>
+
+=item L<Computer Programming Manual (CPM) DID)|Docs::US_DOD::CPM>
+
+=item L<Computer Resources Integrated Support Document (CRISD) DID|Docs::US_DOD::CRISD>
+
+=item L<Computer System Operator's Manual (CSOM) DID|Docs::US_DOD::CSOM>
+
+=item L<Database Design Description (DBDD) DID|Docs::US_DOD::DBDD>
+
+=item L<Engineering Change Proposal (ECP) DID|Docs::US_DOD::ECP>
+
+=item L<Firmware support Manual (FSM) DID|Docs::US_DOD::FSM>
+
+=item L<Interface Design Document (IDD) DID|Docs::US_DOD::IDD>
+
+=item L<Interface Requirements Specification (IRS) DID|Docs::US_DOD::IRS>
+
+=item L<Operation Concept Description (OCD) DID|Docs::US_DOD::OCD>
+
+=item L<Specification Change Notice (SCN) DID|Docs::US_DOD::SCN>
+
+=item L<Software Design Specification (SDD) DID|Docs::US_DOD::SDD>
+
+=item L<Software Development Plan (SDP) DID|Docs::US_DOD::SDP> 
+
+=item L<Software Input and Output Manual (SIOM) DID|Docs::US_DOD::SIOM>
+
+=item L<Software Installation Plan (SIP) DID|Docs::US_DOD::SIP>
+
+=item L<Software Programmer's Manual (SPM) DID|Docs::US_DOD::SPM>
+
+=item L<Software Product Specification (SPS) DID|Docs::US_DOD::SPS>
+
+=item L<Software Requirements Specification (SRS) DID|Docs::US_DOD::SRS>
+
+=item L<System or Segment Design Document (SSDD) DID|Docs::US_DOD::SSDD>
+
+=item L<System or Subsystem Specification (SSS) DID|Docs::US_DOD::SSS>
+
+=item L<Software Test Description (STD) DID|Docs::US_DOD::STD>
+
+=item L<Software Test Plan (STP) DID|Docs::US_DOD::STP>
+
+=item L<Software Test Report (STR) DID|Docs::US_DOD::STR>
+
+=item L<Software Transition Plan (STrP) DID|Docs::US_DOD::STrP>
+
+=item L<Software User Manual (SUM) DID|Docs::US_DOD::SUM>
+
+=item L<Software Version Description (SVD) DID|Docs::US_DOD::SVD>
+
+=item L<Version Description Document (VDD) DID|Docs::US_DOD::VDD>
 
 =back
 
@@ -517,29 +596,15 @@ L<[Test::STDmaker]|Test::STDmaker> L<[ExtUtils::SVDmaker]|ExtUtils::SVDmaker>
 __DATA__
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 DISTNAME: Docs-US_DOD-STD2167A^
-VERSION : 0.03^
+VERSION : 0.04^
 REPOSITORY_DIR: packages^
 FREEZE: 1^
 
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE:  0.02^
-REVISION: A^
+PREVIOUS_RELEASE:  0.03^
+REVISION: C^
+
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 ABSTRACT: 2167A Software Development Standards, Specifications and Data Item Description PODs^
 TITLE   : Software Development Standards, Specifications and Data Item Description PODs^
@@ -571,6 +636,44 @@ PREREQ_PM:  ^
 TESTS: t/Docs/US_DOD/STD2167A.t^
 EXE_FILES:  ^
 
+CHANGES:
+
+Changes are as follows:
+
+\=over 4
+
+\=item Docs::US_DOD::STD2167A 0.03
+
+Retarded. Sorry testers. 
+
+Version 0.02 loaded test file t/Docs/US_DOD/STD2167A.t but
+specified test file t/docs/US_DOD/STD2167A.t.
+Works on case insensitive file specs OS such as MsDOS but
+fails on case sensitive file specs OS such as Unix
+
+Changed the test file
+
+From:
+
+ t/docs/US_DOD/STD2167A.t
+
+To:
+
+ t/Docs/US_DOD/STD2167A.t
+
+
+\=item Docs::US_DOD::STD2167A 0.04
+
+Another case insensitive issue. The STrP has one lower case
+letter. Make changes so everything should match the case.
+Unix file specifications are case sensitive while
+Microsoft's are not.
+
+\=back
+
+^
+
+
 DOCUMENT_OVERVIEW:
 This document releases ${DISTNAME} version ${VERSION} and
 provides a description of the inventory, installation
@@ -611,8 +714,22 @@ MANIFEST, updates file versions and creates .tar.gz distribution
 file from a SVD text database in a format consistent with
 L<DataPort::FileType::FormDB>.
 
+The dependency of the program modules in the US DOD STD2167A bundle is as follows:
+ 
+ File::Package File::SmartNL File::TestPath Text::Scrub
+
+     Test::Tech
+
+        DataPort::FileType::FormDB DataPort::DataFile DataPort::Maker 
+        File::AnySpec File::Data File::PM2File File::SubPM Text::Replace 
+        Text::Table
+
+            Test::STDmaker ExtUtils::SVDmaker
+
+
 \=back
 
+
 ^
 
 LICENSE:
@@ -667,25 +784,6 @@ ADVISED OF NEGLIGENCE OR OTHERWISE) ARISING IN
 ANY WAY OUT OF THE POSSIBILITY OF SUCH DAMAGE.
 ^
 
-CHANGES:
-Retarded. Sorry testers. 
-
-Version 0.02 loaded test file t/Docs/US_DOD/STD2167A.t but
-specified test file t/docs/US_DOD/STD2167A.t.
-Works on case insensitive file specs OS such as MsDOS but
-fails on case sensitive file specs OS such as Unix
-
-Changed the test file
-
-From:
-
- t/docs/US_DOD/STD2167A.t
-
-To:
-
- t/Docs/US_DOD/STD2167A.t
-
-^
 
 INSTALLATION:
 To installed the release file, use the CPAN module in the Perl release
@@ -759,80 +857,126 @@ extension for a Software Vesion Description database file
 ^
 
 SEE_ALSO:
-The following documents establish the requirements for Perl Modules and
-PODs:
+
+Modules with end-user functional interfaces 
+relating to US DOD 2167A automation are
+as follows:
 
 \=over 4
 
-\=item Programing Perl
+\=item L<Test::STDmaker|Test::STDmaker>
 
-Programming Perl, Third Edition, by Larry Wall, Tom Christiansen and Jon Orwant
+\=item L<ExtUtils::SVDmaker|ExtUtils::SVDmaker>
 
-\=item US DOD 2167A Standards, DIDs and related Documents
+\=item L<DataPort::FileType::FormDB|DataPort::FileType::FormDB>
+
+\=item L<DataPort::DataFile|DataPort::DataFile>
+
+\=item L<Test::Tech|Test::Tech>
+
+\=item L<Test|Test>
+
+\=item L<Data::Dumper|Data::Dumper>
+
+\=item L<Test::STD::Scrub|Test::STD::Scrub>
+
+\=item L<Test::STD::STDutil|Test::STD::STDutil>
+
+\=item L<File::FileUtil|File::FileUtil>
+
+\=back
+
+The design modules for L<Test::STDmaker|Test::STDmaker>
+have no other conceivable use then to support the
+L<Test::STDmaker|Test::STDmaker> functional interface. 
+The  L<Test::STDmaker|Test::STDmaker>
+design module are as follows:
 
 \=over 4
 
-\=item  L<[Computer Operation Manual (COM) DID]|Docs::US_DOD::COM>
+\=item L<Test::STD::Check|Test::STD::Check>
 
-\=item L<[Computer Programming Manual (CPM) DID)]|Docs::US_DOD::CPM>
+\=item L<Test::STD::FileGen|Test::STD::FileGen>
 
-\=item L<[Computer Resources Integrated Support Document (CRISD) DID]|Docs::US_DOD::CRISD>
+\=item L<Test::STD::STD2167|Test::STD::STD2167>
 
-\=item L<[Computer System Operator's Manual (CSOM) DID]|Docs::US_DOD::CSOM>
+\=item L<Test::STD::STDgen|Test::STD::STDgen>
 
-\=item L<[Database Design Description (DBDD) DID]|Docs::US_DOD::DBDD>
+\=item L<Test::STDtype::Demo|Test::STDtype::Demo>
 
-\=item L<[Engineering Change Proposal (ECP) DID]|Docs::US_DOD::ECP>
+\=item L<Test::STDtype::STD|Test::STDtype::STD>
 
-\=item L<[Firmware support Manual (FSM) DID]|Docs::US_DOD::FSM>
-
-\=item L<Interface Design Document (IDD) DID]|Docs::US_DOD::IDD>
-
-\=item L<[Interface Requirements Specification (IRS) DID]|Docs::US_DOD::IRS>
-
-\=item L<[Operation Concept Description (OCD) DID]|Docs::US_DOD::OCD>
-
-\=item L<[Specification Change Notice (SCN) DID]|Docs::US_DOD::SCN>
-
-\=item L<[Software Design Specification (SDD) DID]|Docs::US_DOD::SDD>
-
-\=item L<[Software Development Plan (SDP) DID]|Docs::US_DOD::SDP> 
-
-\=item L<[Software Input and Output Manual (SIOM) DID]|Docs::US_DOD::SIOM>
-
-\=item L<[Software Installation Plan (SIP) DID]|Docs::US_DOD::SIP>
-
-\=item L<[Software Programmer's Manual (SPM) DID]|Docs::US_DOD::SPM>
-
-\=item L<[Software Product Specification (SPS) DID]|Docs::US_DOD::SPS>
-
-\=item L<[Software Requirements Specification (SRS) DID]|Docs::US_DOD::SRS>
-
-\=item L<[System or Segment Design Document (SSDD) DID]|Docs::US_DOD::SSDD>
-
-\=item L<[System or Subsystem Specification (SSS) DID]|Docs::US_DOD::SSS>
-
-\=item L<[Software Test Description (STD) DID]|Docs::US_DOD::STD>
-
-\=item L<[Software Test Plan (STP) DID]|Docs::US_DOD::STP>
-
-\=item L<[Software Test Report (STR) DID]|Docs::US_DOD::STR>
-
-\=item L<[Software Transition Plan (STrP) DID]|Docs::US_DOD::STrP>
-
-\=item L<[Software User Manual (SUM) DID]|Docs::US_DOD::SUM>
-
-\=item L<[Software Version Description (SVD) DID]|Docs::US_DOD::SVD>
-
-\=item L<[Version Description Document (VDD) DID]|Docs::US_DOD::VDD>
+\=item L<Test::STDtype::Verify|Test::STDtype::Verify>
 
 \=back
 
-\=item US DOD STD2167A Automation
 
-L<[Test::STDmaker]|Test::STDmaker> L<[ExtUtils::SVDmaker]|ExtUtils::SVDmaker>
+Some US DOD 2167A Software Development Standard, DIDs and
+other related documents that complement the 
+US DOD 2167A automation are as follows:
+
+\=over 4
+
+\=item L<US DOD Software Development Standard|Docs::US_DOD::STD2167A>
+
+\=item L<US DOD Specification Practices|Docs::US_DOD::STD490A>
+
+\=item L<Computer Operation Manual (COM) DID|Docs::US_DOD::COM>
+
+\=item L<Computer Programming Manual (CPM) DID)|Docs::US_DOD::CPM>
+
+\=item L<Computer Resources Integrated Support Document (CRISD) DID|Docs::US_DOD::CRISD>
+
+\=item L<Computer System Operator's Manual (CSOM) DID|Docs::US_DOD::CSOM>
+
+\=item L<Database Design Description (DBDD) DID|Docs::US_DOD::DBDD>
+
+\=item L<Engineering Change Proposal (ECP) DID|Docs::US_DOD::ECP>
+
+\=item L<Firmware support Manual (FSM) DID|Docs::US_DOD::FSM>
+
+\=item L<Interface Design Document (IDD) DID|Docs::US_DOD::IDD>
+
+\=item L<Interface Requirements Specification (IRS) DID|Docs::US_DOD::IRS>
+
+\=item L<Operation Concept Description (OCD) DID|Docs::US_DOD::OCD>
+
+\=item L<Specification Change Notice (SCN) DID|Docs::US_DOD::SCN>
+
+\=item L<Software Design Specification (SDD) DID|Docs::US_DOD::SDD>
+
+\=item L<Software Development Plan (SDP) DID|Docs::US_DOD::SDP> 
+
+\=item L<Software Input and Output Manual (SIOM) DID|Docs::US_DOD::SIOM>
+
+\=item L<Software Installation Plan (SIP) DID|Docs::US_DOD::SIP>
+
+\=item L<Software Programmer's Manual (SPM) DID|Docs::US_DOD::SPM>
+
+\=item L<Software Product Specification (SPS) DID|Docs::US_DOD::SPS>
+
+\=item L<Software Requirements Specification (SRS) DID|Docs::US_DOD::SRS>
+
+\=item L<System or Segment Design Document (SSDD) DID|Docs::US_DOD::SSDD>
+
+\=item L<System or Subsystem Specification (SSS) DID|Docs::US_DOD::SSS>
+
+\=item L<Software Test Description (STD) DID|Docs::US_DOD::STD>
+
+\=item L<Software Test Plan (STP) DID|Docs::US_DOD::STP>
+
+\=item L<Software Test Report (STR) DID|Docs::US_DOD::STR>
+
+\=item L<Software Transition Plan (STrP) DID|Docs::US_DOD::STrP>
+
+\=item L<Software User Manual (SUM) DID|Docs::US_DOD::SUM>
+
+\=item L<Software Version Description (SVD) DID|Docs::US_DOD::SVD>
+
+\=item L<Version Description Document (VDD) DID|Docs::US_DOD::VDD>
 
 \=back
+
 ^
 
 HTML:
